#
# spec file for package htmldoc
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           htmldoc
Version:        1.9.1
Release:        bp153.1.17
Summary:        HTML Processor that Generates HTML, PostScript, and PDF Files
License:        LGPL-2.1+
Group:          Productivity/Publishing/HTML/Tools
Url:            https://michaelrsweet.github.io/htmldoc/index.html
Source:         https://github.com/michaelrsweet/htmldoc/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fltk-devel
BuildRequires:  gcc-c++
BuildRequires:  libXpm-devel
BuildRequires:  libgcrypt-devel
BuildRequires:  libgnutls-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  update-desktop-files
BuildRequires:  zlib-devel

%description
HTMLDOC converts HTML source files into indexed HTML, PostScript, or
Portable Document Format (PDF) files that can be viewed online or printed.

%prep
%setup -q

%build
%configure \
  --with-gui
make %{?_smp_mflags} V=1

%install
%make_install
# Workaround faulty installation
mv -f %{buildroot}%{buildroot}/* \
  %{buildroot}
# Get rid of unvanted files
rm -rf %{buildroot}/home %{buildroot}%{_datadir}/doc/%{name}
# Update desktop file
%suse_update_desktop_file -r %{name} Development Documentation
%suse_update_desktop_file %{name} -G%{name}

%files
%doc CHANGES.md COPYING README.md
%{_bindir}/htmldoc
%{_datadir}/htmldoc
%{_datadir}/pixmaps/htmldoc.xpm
%{_datadir}/mime/packages/htmldoc.xml
%{_datadir}/applications/htmldoc.desktop
%{_mandir}/man1/htmldoc.1%{ext_man}

%changelog
* Mon Dec  4 2017 mpluskal@suse.com
- Update to new version 1.9.1:
  * Fixed monospace font size issue
  * Added support for reproducible builds
  * Added limited support for the HTML 4.0 SPAN element
  * Added (extremely limited) UTF-8 support for input files
  * Fixed buffer underflow for (invalid) short HTML comments
  * Now indent PRE text, by popular request.
  * EPUB output now makes sure that <element property> is written
    as <element property="property">.
  * Now support both NAME and ID for table-of-contents targets.
  * Added support for repeating a single header row for tables that
    span multiple pages
  * Added support for embedding the current filename/URL in the
    header or footer
  * Added EPUB support
  * Added Markdown support
  * Fixed a regression in header/footer image scaling
  * Documentation updates
  * Compiler fixes
  * Fixed a bug when running HTMLDOC as a macOS application.
  * Updated the bundled libpng to v1.6.29.
  * And many more
- Drop upstreamed htmldoc-cups_rand.patch and no longer needed
  htmldoc-docpath.diff
- Lots of spec file cleaning
- Use gnutls/gcrypt for crypto support as openssl support is gone
* Sat Mar 11 2017 sfalken@opensuse.org
- Edited %%files to clear unpackaged files builderror in
  openSUSE:Factory
* Mon May  2 2016 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Use macro for configure
* Wed Feb 25 2015 benoit.monin@gmx.fr
- update to version 1.8.28:
  * Updated default PDF version to 1.4.
  * SECURITY: Fixed three buffer overflow issues when reading AFM
    files and parsing page sizes.
  * Fixed incompatibility with Fortify's version of strcpy, which
    does not work properly with variable-length arrays (STR #235)
  * Fixed compilation against PNG library 1.5 or later (STR #243)
  * Fixed documentation errors (PR #6593, PR #6595)
  * Marked Zapf-Dingbats as a standard font (STR #198)
  * Fixed GPL license text in GUI (STR #222)
  * Fixed a table formatting problem when a column has multiple
    colspan values (PR #6709)
  * Fixed parsing of HTML comments (STR #181)
  * Fixed potential out-of-bounds read in table-of-contents
    rendering code (STR #183)
  * Fixed handling of image URLs with ampersands in them (STR #186)
  * Fixed top/bottom margins for logo and header/footer images
    (STR #174)
  * Fixed image alignment bug (Bug #231)
  * Fixed X11 build problem (Bug #243)
- add source url
- drop the following patches after upstream fix:
  * htmldoc_CVE-2009-3050_535943.diff
  * htmldoc-fortify.diff
  * htmldoc-libpng15.diff
  * htmldoc-link-x11.patch
- refresh patch htmldoc-docpath.diff
- add patch htmldoc-cups_rand.patch to work around a build error
  (upstream bug #510)
- remove now unused --with-fltk configure options
- set datadir for make install
- do not package doc/ source directory: documentation is already
  provided by htmldoc.pdf
- remove COMPILE.txt from doc: useless in a rpm
- add -q to %%setup to avoid spamming the build log
* Fri Apr 19 2013 dimstar@opensuse.org
- Add htmldoc-link-x11.patch: link the GUI app against libX11.
* Tue Sep  4 2012 pgajdos@suse.com
- builds also against libpng15
  * libpng15.patch
* Tue Dec 20 2011 coolo@suse.com
- add autoconf as buildrequire to avoid implicit dependency
* Tue Dec 20 2011 coolo@suse.com
- remove call to suse_update_config (very old work around)
* Mon Feb 15 2010 rguenther@suse.de
- Fix stricter fortification fallout with GCC 4.5.
* Fri Dec 11 2009 lmuelle@suse.de
- Fix buffer overflow in the set_page_size function; CVE-2009-3050;
  (bnc#535943).
* Thu Aug  3 2006 lmuelle@suse.de
- Update to version 1.8.27.
  + Fixed a crash bug that appeared when more than 10 blank
    pages were present in a document (PR #6223)
  + Color changes were not reflected in PRE text (STR #129)
  + Remote URLs did not always work on older operating
    systems (PR #6179)
  + Image filenames using %% escapes were not decoded
    properly.
  + Rows using BGCOLOR that spanned across multiple pages
    did not render properly (PR #6149)
  + Rows no longer start on a new page due to a cell with
    both HEIGHT and ROWSPAN specified (PR #6086)
  + CMYK JPEG images caused HTMLDOC to crash (PR #6106)
  + Table cell width calculations didn't always account for
    the proper minimum width (STR #121)
  + Images were not copied when generating indexed HTML
    output to a directory (STR #117)
  + Changing the bottom margin resulted in text that was
    formatted below the bottom margin.
  + The Monospace-Oblique font was not embedded properly in
    PDF files.
  + Outline and keyword strings in PDF files are now stored
    as Unicode (STR #113)
  + The Flate compression code could get in an infinite
    loop if it ran out of memory (STR #101)
  + Book files saved from the GUI did not handle filenames
    with spaces (STR #105)
  + Fixed and re-enabled the ASCII85Device filter support
    in PostScript Level 2/3 output (STR #116)
  + Character entities in the first word of a file were not
    rendered properly (STR #111)
  + Fixed-size table columns were incorrectly resized when
    a table width was also specified and there was extra
    space to distribute (PR #6062)
  + Text could "walk" up or down when in-line images were
    used (PR #6034)
  + Row backgrounds incorrectly replaced cell backgrounds
    when the first cell in a row used ROWSPAN (PR #6033, PR
    [#6036])
  + HTMLDOC did not correctly parse FONT FACE attributes
    (PR #6006)
  + Images in Level 2/3 PostScript output did not work on
    some printers (PR #6000)
  + The GUI did not use the first page header (PR #5978)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Nov 22 2005 lmuelle@suse.de
- Update to version 1.8.25.
* Wed Dec  8 2004 lmuelle@suse.de
- Update to version 1.8.24; [#43261].
* Mon May 17 2004 lmuelle@suse.de
- Add -fno-strict-aliasing to CFLAGS.
* Sun Mar 21 2004 ro@suse.de
- removed .orig file
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr
* Mon Feb 24 2003 gd@suse.de
- update to version 1.8.23
* Fri Aug 16 2002 ro@suse.de
- removed empty post/postun scripts (#17875) (again)
* Fri Aug 16 2002 gd@suse.de
- update to version 1.8.21
* Mon Aug 12 2002 ro@suse.de
- fix compilation with new fltk
* Thu Jul  4 2002 gd@suse.de
- update to version 1.8.20
- added diff to correct DOCDIR-path and missing fonts
- cleanups (%%files, %%{_mandir})
* Tue Feb  5 2002 gd@suse.de
- added libpng to neededforbuild
* Mon Feb  4 2002 gd@suse.de
- update to version 1.8.18
- the gui finally compiles with fltk-1.1.0b10
- added libjpeg to neededforbuild
* Thu Dec  6 2001 schwab@suse.de
- Fix fltk configuration.
* Thu Dec  6 2001 gd@suse.de
- fixed buildroot again
* Thu Dec  6 2001 ro@suse.de
- fixed format of changes file (again)
* Tue Dec  4 2001 gd@suse.de
- added FLTKCONFIG-path
- fixed neededforbuild
- fixed buildroot
* Mon Dec  3 2001 gd@suse.de
- fixed needeforbuild
* Mon Nov 26 2001 gd@suse.de
- update to 1.8.16
* Sat Oct  6 2001 gd@suse.de
- start
